@@ -33,7 +33,13 @@ import shutil
 if sys.platform=='win32':
 	import win32_helper
 
-print "DeVeDe 2.9"
+try:
+	import psyco
+	psyco.full()
+except ImportError:
+	print 'Psyco not installed, the program will just run slower'
+
+print "DeVeDe 2.13"
 
 # append the directories where we install the devede's own modules
 tipo=-1
@@ -64,27 +70,69 @@ if found==False:
 		found=False	
 
 if tipo==0:
-	gettext.bindtextdomain('devede', '/usr/share/locale')
-	arbol=gtk.glade.XML("/usr/share/devede/devede.glade",domain="devede")
+	#gettext.bindtextdomain('devede', '/usr/share/locale')
+	#Note also before python 2.3 you need the following if
+	#you need translations from non python code (glibc,libglade etc.)
+	#there are other access points to this function
+	#gtk.glade.bindtextdomain("devede","/usr/share/locale")
+	#arbol=gtk.glade.XML("/usr/share/devede/devede.glade",domain="devede")
 	# append the directories where we install the devede's own modules
+
+	share_locale="/usr/share/locale"
+	glade="/usr/share/devede/devede.glade"
 	sys.path.append("/usr/lib/devede")
 	font_path="/usr/share/devede"
 elif tipo==1:
 	# if the files aren't at /usr, try with /usr/local
-	gettext.bindtextdomain('devede', '/usr/local/share/locale')
-	arbol=gtk.glade.XML("/usr/local/share/devede/devede.glade",domain="devede")
+	#gettext.bindtextdomain('devede', '/usr/share/locale')
+	#Note also before python 2.3 you need the following if
+	#you need translations from non python code (glibc,libglade etc.)
+	#there are other access points to this function
+	#gtk.glade.bindtextdomain("devede","/usr/share/locale")
+	#arbol=gtk.glade.XML("/usr/local/share/devede/devede.glade",domain="devede")
+
+	share_locale="/usr/share/locale" # Are you sure?
+	# if the files aren't at /usr, try with /usr/local
+	glade="/usr/local/share/devede/devede.glade"
 	sys.path.append("/usr/local/lib/devede")
 	font_path="/usr/local/share/devede"
 elif tipo==2:
-# if the files aren't at /usr/local, try with ./
-	gettext.bindtextdomain('devede', './po/')
-	arbol=gtk.glade.XML("./devede.glade",domain="devede")
+	# if the files aren't at /usr/local, try with ./
+	#gettext.bindtextdomain('devede', './po/')
+	#Note also before python 2.3 you need the following if
+	#you need translations from non python code (glibc,libglade etc.)
+	#there are other access points to this function
+	#gtk.glade.bindtextdomain("devede","/usr/share/locale")
+	#arbol=gtk.glade.XML("./devede.glade",domain="devede")
+	
+	# if the files aren't at /usr/local, try with ./
+	share_locale="./po/"
+	glade="./devede.glade"
 	sys.path.append("./")
 	font_path=os.getcwd()#"./"
 else:
 	print "Can't locate extra files. Aborting."
 	sys.exit(1)
 
+
+#####################
+#   GetText Stuff   #
+#####################
+
+gettext.bindtextdomain('devede',share_locale)
+locale.setlocale(locale.LC_ALL,"")
+gettext.textdomain('devede')
+gettext.install("devede",localedir=share_locale,unicode=1) # None is sys default locale
+#   Note also before python 2.3 you need the following if
+#   you need translations from non python code (glibc,libglade etc.)
+#   there are other access points to this function
+gtk.glade.bindtextdomain("devede",share_locale)
+arbol=gtk.glade.XML(glade,domain="devede")
+#   To actually call the gettext translation functions
+#   just replace your strings "string" with gettext("string")
+#   The following shortcut are usually used:
+_ = gettext.gettext
+
 try:
 	from devede_other import *
 except:
@@ -289,7 +337,7 @@ def set_file_values(arbol,global_vars):
 
 	w=arbol.get_widget("aspect_ratio")
 	
-	if global_vars["disctocreate"]=="dvd":
+	if (global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx"):
 		if w.get_active():
 			global_vars["current_file"]["aspect"]=1.77777777
 		else:
@@ -297,6 +345,11 @@ def set_file_values(arbol,global_vars):
 	else:
 		global_vars["current_file"]["aspect"]=1.33333333
 
+	w=arbol.get_widget("sub_codepage")
+	global_vars["current_file"]["sub_codepage"]=w.child.get_text()
+	w=arbol.get_widget("sub_up")
+	global_vars["current_file"]["subtitles_up"]=w.get_active()
+
 	retorno,resx,resy=get_resolution_from_buttons(arbol,pal)
 	global_vars["current_file"]["resolution"]=retorno
 	
@@ -449,7 +502,7 @@ def get_recomended_resolution(arbol,global_vars,pal,blind):
 		elif global_vars["disctocreate"]=="svcd":
 			resx=480
 			resy=nheigh1
-		else: # dvd
+		else: # dvd o divx
 			if (global_vars["current_file"]["owidth"]<=352):
 				resx=352
 				if (global_vars["current_file"]["oheight"]<=nheigh2):
@@ -531,7 +584,7 @@ def set_final_size(arbol,global_vars,blind=False):
 			w.set_value(2001)
 		return
 	
-	# DVD
+	# DVD o DIVX
 
 	if (global_vars["current_file"]["width"]<=480):
 		if (global_vars["current_file"]["height"]<=nheigh2):
@@ -579,13 +632,9 @@ def set_values_of_file(arbol,global_vars,filename,blind=False):
 
 	if not sys.platform=='win32':
 		handler=subprocess.Popen('mplayer -identify -ao null -vo null -frames 0 "'+filename+'" 2>/dev/null |grep ID',shell=True,bufsize=32768,stdout=subprocess.PIPE)
-	else:
-		#TODO
-		bin=os.path.join(os.getcwd(),"bin"+os.sep+"mplayer.exe")
-		grep='"'+os.path.join(os.getcwd(),"bin"+os.sep+"grep.exe")+'"'
-		mplayer='"'+os.path.join(os.getcwd(),"bin"+os.sep+"mplayer.exe")+'"'
-		zz = mplayer+' -identify -ao null -vo null -frames 0 "'+filename+'" 2>null | '+grep+' ID'
-		handler=subprocess.Popen(zz,bufsize=32768,stdout=subprocess.PIPE)
+	else:		
+		zz=["mplayer.exe", "-identify", "-ao", "null", "-vo", "null", "-frames", "0", filename]
+		handler=launch_program(zz)
 
 	while True:
 		linea=handler.stdout.readline()
@@ -622,11 +671,8 @@ def set_values_of_file(arbol,global_vars,filename,blind=False):
 	if not sys.platform == 'win32':
 		handler=subprocess.Popen('mplayer -identify -ao null -vo null -frames 1 "'+filename+'" 2>/dev/null |grep ID',shell=True,bufsize=32768,stdout=subprocess.PIPE)
 	else:
-		bin=os.path.join(os.getcwd(),"bin"+os.sep+"mplayer.exe")
-		grep='"'+os.path.join(os.getcwd(),"bin"+os.sep+"grep.exe")+'"'
-		mplayer='"'+os.path.join(os.getcwd(),"bin"+os.sep+"mplayer.exe")+'"'
-		zz = mplayer+' -identify -ao null -vo null -frames 1 "'+filename+'" 2>null | '+grep+' ID'
-		handler=subprocess.Popen(zz,bufsize=32768,stdout=subprocess.PIPE)
+		zz=["mplayer.exe", "-identify", "-ao", "null", "-vo", "null", "-frames", "1", filename]
+		handler=launch_program(zz)
 
 
 	while True:
@@ -642,6 +688,9 @@ def set_values_of_file(arbol,global_vars,filename,blind=False):
 		if linea[:15]=="ID_VIDEO_ASPECT":
 			aspect_ratio=float(linea[16:])
 		if linea[:12]=="ID_VIDEO_FPS":
+			fps2=linea[13:]
+			if ord(fps2[-1])<32:
+				fps2=fps2[:-1]
 			posic=linea.find(".")
 			if posic==-1:
 				fps=int(linea[13:])
@@ -692,6 +741,7 @@ def set_values_of_file(arbol,global_vars,filename,blind=False):
 	global_vars["current_file"]["oheight"]=heigh
 	global_vars["current_file"]["olength"]=length
 	global_vars["current_file"]["ofps"]=fps
+	global_vars["current_file"]["ofps2"]=fps2
 	global_vars["current_file"]["ovrate"]=vrate/1000
 	global_vars["current_file"]["oarate"]=arate/1000
 	global_vars["current_file"]["blackbars"]=0 # black bars, no scale
@@ -709,15 +759,18 @@ def set_values_of_file(arbol,global_vars,filename,blind=False):
 	global_vars["current_file"]["mbd"]=2
 	global_vars["current_file"]["deinterlace"]="none"
 	global_vars["current_file"]["subtitles"]=""
+	global_vars["current_file"]["sub_codepage"]="ISO-8859-1"
+	global_vars["current_file"]["subtitles_up"]=False
 
 	set_final_size(arbol,global_vars,blind)
 	
 	print "Aspect ratio: "+str(aspect_ratio)
-	if global_vars["disctocreate"]=="dvd":
+	if (global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx"):
 		if blind==False:
 			w=arbol.get_widget("aspect_ratio")
 			w.set_sensitive(True)
-		if (aspect_ratio>=1.7777777) and (global_vars["current_file"]["width"]==720):
+		if (aspect_ratio>=1.7777777) and ((global_vars["current_file"]["width"]==720) or (global_vars["disctocreate"]=="divx")):
+			w=arbol.get_widget("aspect_ratio")
 			global_vars["current_file"]["aspect"]=1.77777777
 			if (blind==False) and (global_vars["doing_modify"]==False):
 				w.set_active(True)
@@ -731,6 +784,7 @@ def set_values_of_file(arbol,global_vars,filename,blind=False):
 			w=arbol.get_widget("aspect_ratio")
 			w.set_active(False)
 			w.set_sensitive(False)
+		global_vars["current_file"]["aspect"]=1.33333333
 	global_vars["doing_modify"]=False
 	
 	return True,0
@@ -933,7 +987,10 @@ def set_video_values(arbol,structure,global_vars):
 		if encontrado["fps"]==25:
 			w.set_text("25 (PAL)")
 		elif encontrado["fps"]==30:
-			w.set_text("30 (NTSC)")
+			if (encontrado["ofps"]==24) and ((global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx")):
+				w.set_text("24 (NTSC)")
+			else:
+				w.set_text("30 (NTSC)")
 		else:
 			w.set_text(str(int(encontrado["fps"])))
 		
@@ -1196,6 +1253,10 @@ def addchapter(args,arbol,global_vars):
 	w.unselect_all()
 	w=arbol.get_widget("subtitles_chooser")
 	w.unselect_all()
+	w=arbol.get_widget("sub_codepage")
+	w.child.set_text("ISO-8859-1")
+	w=arbol.get_widget("sub_up")
+	w.set_active(False)
 	w=arbol.get_widget("fileaccept")
 	w.set_sensitive(False)
 	w=arbol.get_widget("preview_film")
@@ -1220,7 +1281,7 @@ def addchapter(args,arbol,global_vars):
 		w.set_value(5001)
 	
 	w=arbol.get_widget("aspect_ratio")
-	if global_vars["disctocreate"]=="dvd":
+	if (global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx"):
 		w.set_sensitive(True)
 	else:
 		w.set_sensitive(False)
@@ -1384,6 +1445,11 @@ def modify_chapter(args,arbol,structure,global_vars):
 	w.unselect_all()
 	if global_vars["chapter_to_modify"]["subtitles"]!="":
 		w.set_filename(global_vars["chapter_to_modify"]["subtitles"])
+		
+	w=arbol.get_widget("sub_codepage")
+	w.child.set_text(global_vars["chapter_to_modify"]["sub_codepage"])
+	w=arbol.get_widget("sub_up")
+	w.set_active(global_vars["chapter_to_modify"]["subtitles_up"])
 	
 	global_vars["current_file"]={}
 	filechoser=arbol.get_widget("moviefile")
@@ -1391,7 +1457,7 @@ def modify_chapter(args,arbol,structure,global_vars):
 	# as soon as we set the filename, there's a SELECTION-CHANGED event, which calls FILECHANGED
 	value_changed("",arbol,global_vars) # set the values
 	w=arbol.get_widget("aspect_ratio")
-	if global_vars["disctocreate"]=="dvd":
+	if (global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx"):
 		w.set_sensitive(True)
 		if global_vars["chapter_to_modify"]["aspect"]>1.6:
 			w.set_active(True)
@@ -1494,7 +1560,7 @@ def value_changed3(args,arbol,global_vars):
 	
 	value_changed("",arbol,global_vars)
 
-	if global_vars["disctocreate"]!="dvd":
+	if (global_vars["disctocreate"]!="dvd"):
 		return
 	if len(global_vars["current_file"])==0:
 		return
@@ -1509,6 +1575,8 @@ def value_changed4(args,arbol,global_vars):
 	w=arbol.get_widget("aspect_ratio")
 	if False==w.get_active():
 		return
+	if (global_vars["disctocreate"]=="divx"):
+		return
 	value_changed("",arbol,global_vars)
 	if len(global_vars["current_file"])==0:
 		return
@@ -1734,11 +1802,25 @@ def preview_ok(args,arbol,global_vars):
 	wpreview=arbol.get_widget("wpreview")
 	wpreview.hide()
 	
+
+	try:
+		fichero=open(global_vars["temp_folder"]+"write_check","w")
+		fichero.write("Testing")
+		fichero.close()
+	except:
+		show_error2(_("Failed to write to the destination directory.\nCheck that you have privileges and free space there."),arbol)
+		return
+		
+	try:
+		os.remove(global_vars["temp_folder"]+"write_check")
+	except:
+		print "Failed to erase the write check file"
+	
 	wprogress=arbol.get_widget("wprogress")
 	wprogress.show()
 	global_vars["cancel_prog"]=False
 	w=arbol.get_widget("seconds_preview")
-	retorno=devede_convert.convert_file(arbol,global_vars,global_vars["current_file"],global_vars["temp_folder"],"movietemp",0.0,1,1,1,w.get_value())
+	retorno=devede_convert.convert_file(arbol,global_vars,global_vars["current_file"],global_vars["temp_folder"],"movietemp",0.0,1,1,1,True,w.get_value())
 	# into CONVERT_FILE we do multiple REFRESH_SCREEN, which explain why we show and hide WPROGRESS
 	wprogress.hide()
 	if retorno==True:
@@ -1822,6 +1904,28 @@ def select_cvd(args,arbol,structure,global_vars):
 	w=arbol.get_widget("frame_division")
 	w.hide()
 
+def select_divx(args,arbol,structure,global_vars):
+
+	global_vars["disctocreate"]="divx"
+	wdisktype=arbol.get_widget("wdisktype")
+	wdisktype.hide()
+	w=arbol.get_widget("dvdsize")
+	w.set_active(4)
+	select_first(arbol,structure,global_vars)
+	w=arbol.get_widget("frame1")
+	w.hide()
+	w=arbol.get_widget("only_convert")
+	w.set_active(True)
+	w=arbol.get_widget("frame5")
+	w.hide()
+	w=arbol.get_widget("frame19")
+	w.hide()
+	w=arbol.get_widget("frame_division")
+	w.hide()
+	w=arbol.get_widget("the_notebook")
+	w2=w.get_nth_page(3)
+	w2.hide()
+
 
 def init_main(arbol,structure,global_vars):
 
@@ -2019,6 +2123,8 @@ def init_main(arbol,structure,global_vars):
 	
 	w=arbol.get_widget("typedvd")
 	w.connect("clicked",select_dvd,arbol,structure,global_vars)
+	w=arbol.get_widget("typedivx")
+	w.connect("clicked",select_divx,arbol,structure,global_vars)
 	w=arbol.get_widget("typevcd")
 	w.connect("clicked",select_vcd,arbol,structure,global_vars)
 	w=arbol.get_widget("typesvcd")
@@ -2060,9 +2166,9 @@ def init_main(arbol,structure,global_vars):
 
 home=get_home_directory()
 
-locale.setlocale(locale.LC_ALL,"")
-gettext.textdomain('devede')
-_ = gettext.gettext
+#locale.setlocale(locale.LC_ALL,"")
+#gettext.textdomain('devede')
+#_ = gettext.gettext
 
 # global variables used (they are stored in a single dictionary to avoid true global variables):
 
@@ -2149,32 +2255,29 @@ if not sys.platform=='win32':
 	if 127==check_program("spumux --help"):
 		errors+="spumux\n"
 else:
-	# TODO
-	bin=os.path.join(os.getcwd(),"bin"+os.sep)
-	print bin
 	
 	try:
-		check_program(bin+"mplayer.exe -v")
+		check_program(["mplayer.exe", "-v"])
 	except:
 		errors+="mplayer\n"
 	try:
-		check_program(bin+"mencoder.exe -msglevel help")
+		check_program(["mencoder.exe", "-msglevel", "help"])
 	except:
 		errors+="mencoder\n"
 	try:
-		check_program(bin+"dvdauthor.exe --help")
+		check_program(["dvdauthor.exe", "--help"])
 	except:
 		errors+="dvdauthor\n"
 	try:
-		check_program(bin+"vcdimager.exe --help")
+		check_program(["vcdimager.exe", "--help"])
 	except:
 		errors+="vcdimager\n"
 	try:
-		check_program(bin+"mkisofs.exe -help")
+		check_program(["mkisofs.exe", "-help"])
 	except:
 		errors+="mkisofs\n"
 	try:
-		check_program(bin+"spumux.exe --help")
+		check_program(["spumux.exe", "--help"])
 	except:
 		errors+="spumux\n"
 
