@@ -101,7 +101,7 @@ def erase_all_files(filefolder,filename,global_vars):
 	except OSError:
 		print newfilename.strip()+"_sub.xml not found"
 
-	if global_vars["disctocreate"]=="dvd":
+	if (global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx"):
 		try:
 			os.remove(newfilename.strip()+".iso")
 		except OSError:
@@ -119,7 +119,10 @@ def erase_all_files(filefolder,filename,global_vars):
 	try:
 		z=glob.glob(newfilename+"_[0-9][0-9]_[0-9][0-9]"+".mpg")
 		for x in z:
-			os.remove(x)
+			try:
+				os.remove(x)
+			except OSError:
+				print str(x)+" not found to remove"
 		#os.remove(newfilename+"_??_??.mpg") # ??_?? is bash regex, seems to also work with os.remove
 	except OSError:
 		print newfilename ,  "._??_?? not found"
@@ -143,7 +146,7 @@ def create_filename(filename,title,file):
 	return currentfile
 
 #TODO
-def add_subtitle(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total):
+def add_subtitle(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total,erase_temporary_files):
 
 	""" Adds the subtitles to a movie """
 	
@@ -155,8 +158,7 @@ def add_subtitle(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 	percent1=((100*(cfiles+.5))/total)
 	ptotal.set_fraction(percent1/100)
 	ptotal.set_text(str(int(percent1))+"%")
-	ppartial.set_fraction(0)
-	ppartial.set_text("0%")
+	ppartial.pulse()
 	refresh_screen()
 	refresh_screen()
 	currentfile=create_filename(filefolder+filename,titles,files)
@@ -173,7 +175,47 @@ def add_subtitle(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 		fichero.write('<subpictures>\n\t<stream>')
 		fichero.write('\n\t\t<textsub filename="'+afile["subtitles"]+'"')
 		fichero.write('\n\t\tfont="devedesans.ttf"')
+		if ((afile["sub_codepage"]!="") and (afile["sub_codepage"]!="ASCII")):
+			fichero.write('\n\t\tcharacterset="'+afile["sub_codepage"]+'"')
 		fichero.write('\n\t\thorizontal-alignment="center"')
+
+		if (afile["fps"]==25):
+			ancho=716
+			alto=572
+			tamanofont=27
+		else:
+			ancho=716
+			alto=476
+			tamanofont=27
+
+		margin_hor=int((58*ancho)/720)
+		margin_vert=int((28*alto)/576)
+		bottom_margin=margin_vert
+
+		fichero.write('\n\t\tmovie-width="'+str(ancho-4)+'"')
+		fichero.write('\n\t\tmovie-height="'+str(alto-4)+'"')
+		fichero.write('\n\t\tleft-margin="'+str(margin_hor)+'"')
+		fichero.write('\n\t\tright-margin="'+str(margin_hor)+'"')
+
+		if afile["subtitles_up"]:
+			tamanofont-=1
+			bottom_margin=4+(alto/8) # put it in the border of 16:9 aspect ratio
+
+		fichero.write('\n\t\tbottom-margin="'+str(bottom_margin)+'"')
+		fichero.write('\n\t\ttop-margin="'+str(margin_vert)+'"')
+
+		fichero.write('\n\t\tfontsize="'+str(tamanofont)+'.0"')
+
+		if (afile["fps"]==30):
+			if (afile["ofps"]==24) and ((global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx")):
+				fps_out="24000/1001"
+			else:
+				fps_out="30000/1001"
+		else:
+			fps_out="25"
+
+		fichero.write('\n\t\tmovie-fps="'+str(fps_out)+'"')
+		fichero.write('\n\t\tsubtitle-fps="'+str(fps_out)+'"')
 		fichero.write('\n\t\tvertical-alignment="bottom" />')
 		fichero.write("\n\t</stream>\n</subpictures>")
 		fichero.close()
@@ -194,37 +236,74 @@ def add_subtitle(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 		
 	comando+=" "+filefolder+filename+"_sub.xml < "+currentfile+" > "+currentfile+".sub"
 	print "Launch: "+comando
-	handle=subprocess.Popen(comando,bufsize=8192,shell=True)
+
+	handle=subprocess.Popen(comando,shell=True,bufsize=32767, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 		
 	while (None==handle.poll()):
+		if sys.platform=='win32':
+			try:
+				v1=win32_helper.recv_some(handler)
+			except Exception:
+				break
+		else:
+			v1,v2,v3=select.select([handle.stderr,handle.stdout],[],[],0)
+
+		for elem in v1:
+			temporal=elem.readline(80)
+			print temporal,
+			ppartial.pulse()
+			position=temporal.find("STAT: ")
+			if (position!=-1):
+				position2=temporal.find(".",position+6)
+				if position2!=-1:
+					ppartial.set_text(temporal[position:position2])	
 		refresh_screen()
-		time.sleep(1)
-		ppartial.pulse()
+
 		if global_vars["cancel_prog"]:
-			os.kill(handle.pid,signal.SIGKILL)
+			if sys.platform=='win32':
+				try:
+					win32api.TerminateProcess(int(handle._handle), -1)
+				except Exception , err:
+					print "Error: ", err
+			else:
+				handle2=subprocess.Popen("pkill -P "+str(handle.pid),bufsize=8192,shell=True)
 			break
-		
-	handle.wait()
+
+	
+	error_ret=handle.wait()
+	
 	if global_vars["cancel_prog"]:
+		wprogress=arbol.get_widget("wprogress")
+		wprogress.hide()
+		w=arbol.get_widget("w_aborted")
+		w.show()
+		return True
+	
+	if error_ret!=0:
+		wprogress=arbol.get_widget("wprogress")
+		wprogress.hide()
+		show_error2(_("Conversion failed.\nIt seems a bug of SPUMUX."),arbol)
 		return True
 	
 	#TODO
+	if erase_temporary_files:
+		try:
+			os.remove(filefolder+filename+"_sub.xml")
+		except OSError:
+			print "Error removing ", filefolder+filename+"_sub.xml"
+	
 	shutil.move(currentfile+".sub", currentfile)
 	#comando="mv "+currentfile+".sub "+currentfile
 	#print "Launch: "+comando
 	#handle=subprocess.Popen(comando,bufsize=8192,shell=True)
 	#handle.wait()
-	try:
-		os.remove(filefolder+filename+"_sub.xml")
-	except OSError:
-		print "Error removing ", filefolder+filename+"_sub.xml"
 	#comando="rm "+filefolder+filename+"_sub.xml"
 	#print "Launch: "+comando
 	#handle=subprocess.Popen(comando,bufsize=8192,shell=True)
 	#handle.wait()
 	return False
 
-def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total,seconds=0):
+def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total,erase_temporary_files,seconds=0):
 
 	""" Converts a video file to an MPEG1-PS or MPEG2-PS file, compliant with DVD players.
 	TITLES is the current title number; FILES is the current file number into that tile;
@@ -275,12 +354,12 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 			#shutil.copyfile(afile["path"],"\""+currentfile+"\"")
 			handle=subprocess.Popen("copy \""+afile["path"] +"\" \""+ currentfile+"\"", shell=True)
 		else:
-			
 			if afile["subtitles"]=="":
 				handle=subprocess.Popen("ln -s \""+afile["path"]+"\" \""+currentfile+"\"",bufsize=8192,shell=True)
 			else:
 				handle=subprocess.Popen("cp \""+afile["path"]+"\" \""+currentfile+"\"",bufsize=8192,shell=True)
 
+		ppartial.set_text("")
 		while (None==handle.poll()):
 			refresh_screen()
 			time.sleep(1)
@@ -296,11 +375,22 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 				break
 		
 		handle.wait()
+		retorno=handle.returncode
 		if global_vars["cancel_prog"]:
+			wprogress=arbol.get_widget("wprogress")
+			wprogress.hide()
+			w=arbol.get_widget("w_aborted")
+			w.show()
+			return True
+
+		if retorno!=0:
+			wprogress=arbol.get_widget("wprogress")
+			wprogress.hide()
+			show_error2(_("File copy failed\nMaybe you ran out of disk space?"),arbol)
 			return True
 
 		if afile["subtitles"]!="":
-			return add_subtitle(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total)
+			return add_subtitle(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total,erase_temporary_files)
 		return False
 
 	ppartial=arbol.get_widget("progresspartial")
@@ -308,6 +398,10 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 	label=arbol.get_widget("lcreating")
 
 	if global_vars["cancel_prog"]:
+		wprogress=arbol.get_widget("wprogress")
+		wprogress.hide()
+		w=arbol.get_widget("w_aborted")
+		w.show()
 		return True
 	
 	addbars=False
@@ -332,11 +426,11 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 	elif (global_vars["disctocreate"]=="svcd") or (global_vars["disctocreate"]=="cvd"):
 		if max_videorate>2375:
 			max_videorate=2375
-	elif (global_vars["disctocreate"]=="dvd"):
+	elif (global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx"):
 		if max_videorate>8500:
 			max_videorate=8500
 	else:
-		print ("Error, disc format is not DVD, VCD, SVCD or CVD. Contact with the author")
+		print ("Error, disc format is not DVD, DIVX, VCD, SVCD or CVD. Contact with the author")
 		print global_vars["disctocreate"]
 		sys.exit(1)
 
@@ -373,7 +467,7 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 	else:
 		command_var=["mencoder.exe"]
 
-	if global_vars["disctocreate"]=="dvd":
+	if (global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx"):
 		audio_desired_final_rate=48000
 	else:
 		audio_desired_final_rate=44100
@@ -385,21 +479,25 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 		command_var.append("lavcresample="+str(audio_desired_final_rate))
 
 	command_var.append("-oac")
-	command_var.append("lavc")
+	if (global_vars["disctocreate"]=="divx"):
+		command_var.append("mp3lame")
+	else:
+		command_var.append("lavc")
 	command_var.append("-ovc")
 	command_var.append("lavc")
-	command_var.append("-of")
-	command_var.append("mpeg")
-	command_var.append("-mpegopts")
-	if global_vars["disctocreate"]=="dvd":
-		command_var.append("format=dvd")
-	elif global_vars["disctocreate"]=="vcd":
-		command_var.append("format=xvcd")
-	elif (global_vars["disctocreate"]=="svcd") or (global_vars["disctocreate"]=="cvd"):
-		command_var.append("format=xsvcd")
-	else:
-		print "Error, disc format incorrect. Talk with the creator."
-		sys.exit(1)
+	if (global_vars["disctocreate"]!="divx"):
+		command_var.append("-of")
+		command_var.append("mpeg")
+		command_var.append("-mpegopts")
+		if global_vars["disctocreate"]=="dvd":
+			command_var.append("format=dvd:tsaf")
+		elif global_vars["disctocreate"]=="vcd":
+			command_var.append("format=xvcd")
+		elif (global_vars["disctocreate"]=="svcd") or (global_vars["disctocreate"]=="cvd"):
+			command_var.append("format=xsvcd")
+		else:
+			print "Error, disc format incorrect. Talk with the creator."
+			sys.exit(1)
 	
 	halffile=False
 	if seconds!=0:
@@ -420,7 +518,10 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 		command_var.append(str(audiodelay))
 
 	if final_framerate==30:
-		str_final_framerate="30000/1001"
+		if (framerate==24) and ((global_vars["disctocreate"]=="dvd") or (global_vars["disctocreate"]=="divx")):
+			str_final_framerate="24000/1001"
+		else:
+			str_final_framerate="30000/1001"
 		keyintv=18
 	else:
 		str_final_framerate=str(int(final_framerate))
@@ -429,26 +530,45 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 	command_var.append("-ofps")
 	command_var.append(str_final_framerate)
 
+	if global_vars["disctocreate"]=="divx":
+		command_var.append("-ffourcc")
+		command_var.append("DX50")
+	
 	command_var.append("-vf")
 	lineatemp=""
+	
+	acoma=False;
+	
 	if afile["deinterlace"]!="none":
-		lineatemp+="pp="+afile["deinterlace"]+","
+		lineatemp+="pp="+afile["deinterlace"]
+		acoma=True
 
 	if addbars and ((resx_inter!=resx_original) or (resy_inter!=resy_original)):
-		lineatemp+="expand="+str(resx_inter)+":"+str(resy_inter)+":"+str(addx)+":"+str(addy)+","
+		if acoma:
+			lineatemp+=","
+		lineatemp+="expand="+str(resx_inter)+":"+str(resy_inter)+":"+str(addx)+":"+str(addy)
+		acoma=True
 
 	if (resx_inter!=resx_final) or (resy_inter!=resy_final):
-		lineatemp+="scale="+str(resx_final)+":"+str(resy_final)+","
-	lineatemp+="harddup"
+		if acoma:
+			lineatemp+=","
+		lineatemp+="scale="+str(resx_final)+":"+str(resy_final)
+		acoma=True
+	if global_vars["disctocreate"]!="divx":
+		if acoma:
+			lineatemp+=","
+		lineatemp+="harddup"
 	command_var.append(lineatemp)
 	command_var.append("-lavcopts")
 	
 	lavcopts="vcodec="
 	if global_vars["disctocreate"]=="vcd":
 		lavcopts+="mpeg1video"
+	elif global_vars["disctocreate"]=="divx":
+		lavcopts+="mpeg4"
 	else:
 		lavcopts+="mpeg2video"
-		
+	
 	if afile["trellis"]:
 		lavcopts+=":trell"
 	
@@ -459,22 +579,24 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 	elif afile["mbd"]==2:
 		lavcopts+=":mbd=2"
 
-	lavcopts+=":vrc_maxrate="+str(max_videorate)+":vrc_buf_size="
-	
-	if (global_vars["disctocreate"]=="vcd"):
-		lavcopts+="327:vrc_minrate=1152"
-	elif (global_vars["disctocreate"]=="svcd") or (global_vars["disctocreate"]=="cvd"):
-		lavcopts+="917:vrc_minrate=600"
-	elif (global_vars["disctocreate"]=="dvd"):
-		lavcopts+="1835"
-	
-	lavcopts+=":vbitrate="+str(videorate)+":keyint="+str(keyintv)+":acodec="
-	if global_vars["disctocreate"]=="dvd":
-		lavcopts+="ac3"
-	else:
-		lavcopts+="mp2"
 
-	lavcopts+=":abitrate="+str(audiorate)
+	if global_vars["disctocreate"]!="divx":
+		lavcopts+=":vstrict=0:vrc_maxrate="+str(max_videorate)
+		lavcopts+=":vrc_buf_size="
+		if (global_vars["disctocreate"]=="divx"):
+			lavcopts+="1835"
+		elif (global_vars["disctocreate"]=="vcd"):
+			lavcopts+="327:vrc_minrate=1152"
+		elif (global_vars["disctocreate"]=="svcd") or (global_vars["disctocreate"]=="cvd"):
+			lavcopts+="917:vrc_minrate=600"
+		elif (global_vars["disctocreate"]=="dvd"):
+			lavcopts+="1835"
+	
+	lavcopts+=":vbitrate="+str(videorate)
+	
+	if global_vars["disctocreate"]!="divx":
+		lavcopts+=":keyint="+str(keyintv)+":acodec=mp2"
+		lavcopts+=":abitrate="+str(audiorate)
 	if aspect_ratio_final>1.4:
 		lavcopts+=":aspect=16/9"
 	else:
@@ -482,6 +604,11 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 
 	command_var.append(lavcopts)
 	
+	if global_vars["disctocreate"]=="divx":
+		lameopts="abr:br="+str(audiorate)
+		command_var.append("-lameopts")
+		command_var.append(lameopts)
+	
 	currentfile=create_filename(filefolder+filename,titles,files)	
 	command_var.append("-o")
 	command_var.append(currentfile)
@@ -518,7 +645,7 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 	#	v1=win32subprocess.recv_some(handler)
 
 	v1=""
-	while True:
+	while (handler.poll()==None):
 		#if handler.poll() != None:
 		#	break
 		
@@ -550,10 +677,10 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 			else:
 				refresh=False
 				linea=handler.stdout.readline(2400)
-				if linea=="":
-					break
 				if global_vars["cancel_prog"]:
 					break
+				if linea=="":
+					continue
 				if linea[-1]=="\n":
 					break
 				if salta:
@@ -592,7 +719,7 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 					percent2=value
 					ppartial.set_text(str(int(percent2))+"%")
 					refresh=True
-		if (linea=="") or global_vars["cancel_prog"]:
+		if global_vars["cancel_prog"]:
 			break
 		if linea[-1]=="\n":
 			continue
@@ -611,16 +738,32 @@ def convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files
 	print "after handler.wait()\n"
 	retcode=handler.returncode
 	print "after retcode=handler.returncode\n"
+
 	if (retcode!=0) or global_vars["cancel_prog"]:
+	
 		print "Deleting "+currentfile+" due to error or aborting."
-		os.remove(currentfile)
-		if not global_vars["cancel_prog"]:
-			cause=1
-		global_vars["cancel_prog"]=True
-		return True
+		try:
+			os.remove(currentfile)
+		except OSError:
+			print currentfile+" didn't exists"
+		if global_vars["cancel_prog"]:
+			wprogress=arbol.get_widget("wprogress")
+			wprogress.hide()
+			w=arbol.get_widget("w_aborted")
+			w.show()
+			return True
+		else:
+			wprogress=arbol.get_widget("wprogress")
+			wprogress.hide()
+
+			if percent2==120: # still hadn't take a value, so it seems it failed (core dump)
+				show_error2(_("Conversion failed.\nIt seems a bug of Mencoder."),arbol)
+			else:
+				show_error2(_("Conversion failed\nMaybe you ran out of disk space?"),arbol)
+			return True
 
 	if afile["subtitles"]!="":
-		return add_subtitle(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total)
+		return add_subtitle(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total,erase_temporary_files)
 	return False
 
 
@@ -633,7 +776,7 @@ def check_free_space(arbol,filefolder,structure,actions,erase_temporary_files):
 	freespace=''
 	if not sys.platform=='win32':
 		estado=os.statvfs(filefolder) # eg. f="C:\Documents and Settings\Peter Gill\Desktop"
-		freespace=estado.f_bsize*estado.f_bavail/1000
+		freespace=95*estado.f_bsize*estado.f_bavail/100000
 	else:
 		try:
 			spc, bps, fc, tc = win32api.GetDiskFreeSpace(filefolder)
@@ -641,9 +784,8 @@ def check_free_space(arbol,filefolder,structure,actions,erase_temporary_files):
 
 		except ImportError:
 			pass
-
-	print "Freespace ", freespace , "\n"
-	print "estado ", estado, "\n"
+	print "Free space in "+str(filefolder)+": "+str(freespace)
+	print "estatus ", estado, "\n"
 	
 	total=calcula_tamano_total(structure)
 	
@@ -692,7 +834,7 @@ def get_actions(arbol,global_vars):
 		actions=1
 	else:
 		w=arbol.get_widget("create_dvd")
-		if (w.get_active()) or (global_vars["disctocreate"]!="dvd"):
+		if (w.get_active()) or ((global_vars["disctocreate"]!="dvd") and (global_vars["disctocreate"]!="divx")):
 			actions=2
 		else:
 			actions=3
@@ -756,8 +898,7 @@ def create_dvd_structure(arbol,global_vars,filefolder,filename,total,erase_tempo
 	percent1=float((100*(total-2))/total)
 	ptotal.set_fraction(percent1/100)
 	ptotal.set_text(str(int(percent1))+"%")
-	ppartial.set_fraction(0)
-	ppartial.set_text("0%")
+	ppartial.set_text("")
 
 	command=""
 	if sys.platform=='win32':
@@ -773,7 +914,9 @@ def create_dvd_structure(arbol,global_vars,filefolder,filename,total,erase_tempo
 	#	v1=win32subprocess.recv_some(handler)
 	
 	v1=""
-	while True:
+	contador=0
+	chars_to_read=80
+	while (handler.poll()==None):
 		if sys.platform=='win32':
 			try:
 				v1=win32_helper.recv_some(handler)
@@ -782,21 +925,43 @@ def create_dvd_structure(arbol,global_vars,filefolder,filename,total,erase_tempo
 		else:
 			v1,v2,v3=select.select([handler.stderr,handler.stdout],[],[],0)
 
-		for elem in v1:
-			temporal=elem.readline(80)
-			if temporal=="":
-				break
-			if len(temporal)>11:
-				if temporal[0:11]=="INFO: Video":
+		if len(v1)!=0:
+			for elem in v1:
+				temporal=elem.readline(chars_to_read)
+				print temporal,
+				ppartial.pulse()
+				if temporal=="":
+					continue
+				if temporal.find("INFO: Video")!=-1:
 					total2+=1
 					percent2=float((100*total2)/total_films)
 					percent1=float((100*(total-2))/total)+(percent2/total)
 					ptotal.set_fraction(percent1/100)
 					ptotal.set_text(str(int(percent1))+"%")
-					ppartial.set_fraction(percent2/100)
-					ppartial.set_text(str(int(percent2))+"%")
-		refresh_screen()
-		if (temporal=="") or (global_vars["cancel_prog"]):
+				else:
+					position=temporal.find("STAT: VOBU ")
+					if position!=-1:
+						ppartial.set_text("VOBU "+temporal[position+11:temporal.find(" ",position+11)])
+					else:
+						position=temporal.find("STAT: fixing VOBU at ")
+						if (position!=-1):
+							position2=temporal.find("%",position+21)
+							if (position2!=-1):
+								cadena=temporal[position2-2:position2]
+								ppartial.set_text(cadena+"%")
+								ppartial.set_fraction((float(cadena))/100.0)
+								chars_to_read=200
+
+			contador+=1
+			if contador==50:
+				refresh_screen() # if there's always lines, we refresh each 50 lines
+		else:
+			if chars_to_read==80:
+				time.sleep(.2) # as soon as there are no lines, we wait 1/5 of second
+			else:
+				time.sleep(1) # or one second if we are with percentages
+			refresh_screen() # and refresh the screen
+		if (global_vars["cancel_prog"]):
 			break
 	
 	cause=0
@@ -837,17 +1002,12 @@ def create_dvd_structure(arbol,global_vars,filefolder,filename,total,erase_tempo
 		#b=re.compile(filename+"_[0-9][0-9]_[0-9][0-9]")
 		#d=os.listdir(filefolder)
 		print "Newfilename: " + newfilename
-		for file in glob.glob(newfilename+"_[0-9][0-9]_[0-9][0-9]"+".mpg"):
-			print "removing file: " , file
-			os.remove(file)
-
-		#for x in d:
-		#	print x
-		#	if b.findall(x):
-		#		print "remove: " , x
-		#		os.remove(filefolder+x)
-		#handle=subprocess.Popen("rm "+newfilename+"_??_??.mpg",bufsize=8192,shell=True)
-		#handle.wait()
+		for thefile in glob.glob(newfilename+"_[0-9][0-9]_[0-9][0-9]"+".mpg"):
+			print "removing file: " , thefile
+			try:
+				os.remove(thefile)
+			except OSError:
+				print str(thefile)+" not removed because it doesn't exists"
 
 		try:
 			print newfilename+".xml"
@@ -897,18 +1057,18 @@ def create_vcd_structure(arbol,structure,global_vars,filefolder,filename,erase_t
 
 	handler=launch_program(lista,False)
 	while (None==handler.poll()):
-			refresh_screen()
-			time.sleep(1)
-			ppartial.pulse()
-			if global_vars["cancel_prog"]:
-				if sys.platform=='win32':
-					try:
-						win32api.TerminateProcess(int(handler._handle), -1)
-					except Exception , err:
-						print "Error: ", err
-				else:
-					os.kill(handler.pid,signal.SIGKILL)
-				break
+		refresh_screen()
+		time.sleep(1)
+		ppartial.pulse()
+		if global_vars["cancel_prog"]:
+			if sys.platform=='win32':
+				try:
+					win32api.TerminateProcess(int(handler._handle), -1)
+				except Exception , err:
+					print "Error: ", err
+			else:
+				os.kill(handler.pid,signal.SIGKILL)
+			break
 	
 	handler.wait()
 	retcode=handler.returncode
@@ -938,11 +1098,17 @@ def create_vcd_structure(arbol,structure,global_vars,filefolder,filename,erase_t
 		# TODO
 		for file in glob.glob(newfilename+"_[0-9][0-9]_[0-9][0-9]"+".mpg"):
 			print "removing file: " , newfilename
-			os.remove(file)
+			try: 
+				os.remove(file)
+			except OSError:
+				print "not removed because it doesn't exists"
 
 		#handle=subprocess.Popen("rm "+newfilename+".xml",bufsize=8192,shell=True)
 		#handle.wait()
-		os.remove(newfilename+".xml")
+		try:
+			os.remove(newfilename+".xml")
+		except OSError:
+				print "not removed because it doesn't exists"
 	
 	return False
 
@@ -968,12 +1134,13 @@ def create_iso(arbol,global_vars,total,filefolder,filename,erase_temporary_files
 	else:
 		command="mkisofs"
 
-	handler=launch_program([command,"-dvd-video","-v","-o",filefolder+filename+".iso",filefolder+filename])
+	volume="DVD-VIDEO"
+	handler=launch_program([command,"-dvd-video","-V",volume,"-v","-o",filefolder+filename+".iso",filefolder+filename])
 	refresh_screen()
 	temporal=''
 
 	v1=""
-	while True:
+	while (handler.poll()==None):
 		if sys.platform=='win32':
 			try:
 				v1=win32_helper.recv_some(handler)
@@ -985,7 +1152,7 @@ def create_iso(arbol,global_vars,total,filefolder,filename,erase_temporary_files
 		for elem in v1:
 			temporal=elem.readline(80)
 			if temporal=="":
-				break
+				continue
 			punto=temporal.find("done, estimate")
 			if (punto!=-1):
 				if ((temporal[2].isdigit()) and ((temporal[1].isdigit()) or (temporal[1]==" "))):
@@ -997,7 +1164,7 @@ def create_iso(arbol,global_vars,total,filefolder,filename,erase_temporary_files
 					ppartial.set_text(str(int(percent2))+"%")
 
 		refresh_screen()
-		if (temporal=="") or (global_vars["cancel_prog"]):
+		if (global_vars["cancel_prog"]):
 			break
 	cause=0
 	
@@ -1068,11 +1235,12 @@ def create_dvd3(args,arbol,structure,global_vars):
 
 	erase_all_files(filefolder,filename,global_vars)
 
+	# less priority to allow to use the computer without speed penalty while compressing
 	if sys.platform=='win32':
 		handle = win32api.OpenProcess(win32con.PROCESS_ALL_ACCESS, True, win32api.GetCurrentProcessId())
 		win32process.SetPriorityClass(handle, win32process.BELOW_NORMAL_PRIORITY_CLASS)
 	else:
-		os.nice(1) # less priority to allow to use the computer without speed penalty while compressing
+		os.nice(1)
 	# show the progress window, but clear it before
 
 	ppartial=arbol.get_widget("progresspartial")
@@ -1120,7 +1288,7 @@ def create_dvd3(args,arbol,structure,global_vars):
 			files=0
 			for afile in title[1:]:
 				files+=1
-				if False==convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total):
+				if False==convert_file(arbol,global_vars,afile,filefolder,filename,cfiles,titles,files,total,erase_temporary_files):
 					cfiles+=1.0
 				else:
 					break
@@ -1128,18 +1296,7 @@ def create_dvd3(args,arbol,structure,global_vars):
 	# if the conversion fails, check why and show the message
 
 	if global_vars["cancel_prog"]:
-		wprogress.hide()
-		if cause==0:
-			w=arbol.get_widget("w_aborted")
-			w.show()
-			return
-		if cause==1:
-			if percent2==120: # still hadn't take a value, so it seems it failed (core dump)
-				show_error2(_("Conversion failed.\nIt seems a bug of Mencoder."),arbol)
-			else:
-				show_error2(_("Conversion failed\nMaybe you ran out of disk space?"),arbol)
-			return
-
+		return
 
 	# if user is creating a DVD and wanted to do the DVD structure:
 
